@@ -1,6 +1,6 @@
 #!/bin/sh
 # /**************************************************************************
-# *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+# *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
 # *                                                                         *
 # *   This program is free software: you can redistribute it and/or modify  *
 # *   it under the terms of the GNU General Public License as published by  *
@@ -62,16 +62,16 @@ fi
 
 #Now it's time to umount device
 $1 $2
-if [ $? > 0 ]; then
-	echo "Error: \"$1 $2\" returns an a error."
+if [ $? -gt 0 ]; then
+	echo "Error: \"$1 $2\" returns an error."
 	exit 255
 fi
 
 #Now it's time to get: Is it md device or not? If yes -- use mdconfig to remove it.
 if [ "$device_name" =~ md* ]; then
 	$mdconfig -d -u$device_name
-	if [ $? > 0 ]; then
-		echo "Error: \"mdconfig -d -u$device_name\" returns an a error."
+	if [ $? -gt 0 ]; then
+		echo "Error: \"mdconfig -d -u$device_name\" returns an error."
 		exit 255
 	fi
 fi
