@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +16,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #include "sysmenu.h"
 
 system_menu::system_menu()
@@ -36,11 +35,9 @@ system_menu::system_menu()
     CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
-    QString home_path = QDir::homePath();
-
-    base_directory = QString("%1/.local/share/desktop-directories").arg(home_path);
-    base_icon = QString("%1/.local/share/applications").arg(home_path);
-    base_menu = QString("%1/.config/menus/applications-merged/%2.menu").arg(home_path).arg(APP_SHORT_NAME);
+    base_directory = corelib::getGenericDataLocation(QStringList() << "desktop-directories");
+    base_icon = corelib::getGenericDataLocation(QStringList() << "applications");
+    base_menu = corelib::getGenericConfigLocation(QStringList() << "menus" << "applications-merged" << QString("%1.menu").arg(APP_SHORT_NAME));
 }
 
 bool system_menu::add_dom_icons(QDomDocument &menu_xml, QDomElement &root, const QString &prefix_name, const QString &dir_name, const QStringList &iconsList){
