@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2009 by Pavel Zinin (pashazz)                              *
  *   pzinin@gmail.com                                                     *
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -37,10 +37,7 @@ winetricks::winetricks(const QString &prefixName) : QWidget()
     CoreLibClassPointer = reinterpret_cast<CoreLibPrototype*>(libq4wine.resolve("createCoreLib"));
     CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
-    this->winetricks_bin = QDir::homePath();
-    this->winetricks_bin.append("/.config/");
-    this->winetricks_bin.append(APP_SHORT_NAME);
-    this->winetricks_bin.append("/winetricks");
+    this->winetricks_bin = corelib::getAppConfigLocation(QStringList() << "winetricks");
 
     if (!check_script(false)){
         this->winetricks_bin = CoreLib->getWhichOut("winetricks", false);
@@ -220,10 +217,7 @@ void winetricks::downloadwinetricks () {
     /*
      * Downloading winetricks and installing it
      */
-    this->winetricks_bin = QDir::homePath();
-    this->winetricks_bin.append("/.config/");
-    this->winetricks_bin.append(APP_SHORT_NAME);
-    this->winetricks_bin.append("/winetricks");
+    this->winetricks_bin = corelib::getAppConfigLocation(QStringList() << "winetricks");
 
     QFile file(this->winetricks_bin);
 
@@ -243,7 +237,7 @@ void winetricks::downloadwinetricks () {
 
     QStringList args;
     if (!console_args.isEmpty()){
-        // If we have any conslope parametres, we gona preccess them one by one
+        // If we have any console parameters, we will process them one by one
         QStringList cons_args = console_args.split(" ");
         for (int i=0; i<cons_args.count(); i++){
             if (!cons_args.at(i).isEmpty())
@@ -409,6 +403,3 @@ bool winetricks::parse() {
 
     return true;
 }
-
-
-
