@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -42,7 +42,7 @@ MainWindow::MainWindow(const int startState, const QString &run_binary, QWidget
         progress.exec();
     }
 
-    //  importIcons(QString("%1/.local/share/applications/wine/").arg(QDir::homePath()));
+    //  importIcons(QString("%1/applications/wine/").arg(corelib::getGenericDataLocation()));
 
     //exportProcess.close();
     // Base GUI setup
@@ -225,17 +225,14 @@ void MainWindow::setSearchFocus(){
 }
 
 void MainWindow::clearTmp(){
-    QString fileName = QDir::homePath();
-    fileName.append("/.config/");
-    fileName.append(APP_SHORT_NAME);
-    fileName.append("/tmp");
+    QString fileName = corelib::getAppConfigLocation(QStringList() << "tmp");
 
     if (not CoreLib->removeDirectory(fileName)){
         qWarning()<<"[WW] Can't clear "<<fileName;
         return;
     }
 
-    if (!CoreLib->checkDirs(QString("%1/.config/%2").arg(QDir::homePath()).arg(APP_SHORT_NAME), QStringList() << "tmp" << "tmp/cache")){
+    if (!CoreLib->checkDirs(corelib::getAppConfigLocation(), QStringList() << "tmp" << "tmp/cache")){
         return;
     }
 
@@ -256,7 +253,7 @@ void MainWindow::trayIcon_Activate(QSystemTrayIcon::ActivationReason reason){
 void MainWindow::updateIconDesc(const QString &program, QString args, const QString &desc, const QString &console, const QString &desktop){
     /*
      * This is function for selection icons, and displaying
-     * icon informationm like path and description
+     * icon information like path and description
      */
 
     if (args.length()>45){
