@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -491,7 +491,7 @@ void PrefixSettings::txtRunString_Changed(){
     env.append(QString(" WINEARCH='%1' ").arg(comboArchList->currentText()));
     env.append(QString(" WINEDEBUG='%1' ").arg("-all"));
     env.append(QString(" WINEDLLOVERRIDES='' "));
-    env.append(QString(" LANG='' "));
+    env.append(QString(" LC_ALL='' "));
 
     run_string.replace("%ENV_BIN%", CoreLib->getWhichOut("env"));
     run_string.replace("%ENV_ARGS%", env);
