@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -180,7 +180,7 @@ QString WineObject::createEnvString(){
         env.append(QString(" WINEDLLOVERRIDES=%1 ").arg(this->overrideDllList));
 
     if (!this->programLang.isEmpty())
-        env.append(QString(" LANG='%1' ").arg(this->programLang));
+        env.append(QString(" LC_ALL='%1' ").arg(this->programLang));
 
     return env;
 }
@@ -218,7 +218,7 @@ int WineObject::runSys(){
     if (this->useConsole){
         // Owerride " with \" in case of using console app.
         run_string.replace("\"", "\\\"");
-        // If we gona use console output, so exec program is program specified at CONSOLE global variable
+        // If we gonna use console output, so exec program is program specified at CONSOLE global variable
         QString console_bin = CoreLib->getSetting("console", "bin").toString();
         QString console_args = CoreLib->getSetting("console", "args", false).toString();
 
@@ -485,4 +485,3 @@ void WineObject::sendMessage(const QString &message){
 void WineObject::setOverrideDll(const QString &dll_list){
     this->overrideDllList = dll_list;
 }
-
