@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,6 +27,34 @@ corelib* createCoreLib(const bool GUI_MODE){
     return new corelib(GUI_MODE);
 }
 
+const QString corelib::formatLocation(const QStringList &path) {
+    return path.join(QDir::separator());
+}
+
+const QString corelib::getGenericConfigLocation(const QStringList &path) {
+    return formatLocation(QStringList() << QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) << path);
+}
+
+const QString corelib::getAppConfigLocation(const QStringList &path) {
+    return getGenericConfigLocation(QStringList() << APP_SHORT_NAME << path);
+}
+
+const QString corelib::getGenericDataLocation(const QStringList &path) {
+    return formatLocation(QStringList() << QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) << path);
+}
+
+const QString corelib::getAppDataLocation(const QStringList &path) {
+    return getGenericDataLocation(QStringList() << APP_SHORT_NAME << path);
+}
+
+const QString corelib::getGenericCacheLocation(const QStringList &path) {
+    return formatLocation(QStringList() << QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) << path);
+}
+
+const QString corelib::getAppCacheLocation(const QStringList &path) {
+    return getGenericCacheLocation(QStringList() << APP_SHORT_NAME << path);
+}
+
 QList<QStringList> corelib::getWineProcessList(const QString &prefix_name){
     QList<QStringList> proclist;
     QStringList procline;
@@ -73,7 +101,7 @@ QList<QStringList> corelib::getWineProcessList(const QString &prefix_name){
         if (info.isSymLink()) {
             QString fileName = info.symLinkTarget();
 #ifdef DEBUG
-            qDebug()<< "Traget for: " << info.filePath() << " is: " << fileName;
+            qDebug()<< "Target for: " << info.filePath() << " is: " << fileName;
 #endif
             if ((!fileName.contains("wine") && !fileName.contains(".exe")) || fileName.contains(APP_SHORT_NAME)){
                 continue;
@@ -381,8 +409,8 @@ void corelib::checkSettings(){
     }
 
     if (this->getSetting("advanced", "prefixDefaultPath", false).toString().isEmpty()){
-        QString path = QDir::homePath();
-        path.append("/.local/share/wineprefixes");
+        QString path = this->getGenericDataLocation();
+        path.append("/wineprefixes");
 
         QSettings settings(APP_SHORT_NAME, "default");
         settings.beginGroup("advanced");
@@ -1085,7 +1113,7 @@ QString corelib::createDesktopFile(const QString &prefix_name, const QString &di
     QString fileName;
 
     //FIXME:
-    QString base_icon = QString("%1/.local/share/applications/").arg(QDir::homePath());
+    QString base_icon = QString("%1/applications/").arg(this->getGenericDataLocation());
 
 #ifdef _OS_DARWIN_
     QString embedded_icon_path = QString("%1/%2.app/Contents/Resources/icons/share/q4wine/icons/").arg(APP_PREF, APP_NAME);
@@ -1102,9 +1130,7 @@ QString corelib::createDesktopFile(const QString &prefix_name, const QString &di
         fileName.append(dir_name);
         fileName.append("/");
     } else {
-        fileName = QDir::homePath();
-        fileName.append("/.config/");
-        fileName.append(APP_SHORT_NAME);
+        fileName = this->getAppConfigLocation();
         fileName.append("/tmp/");
     }
 
@@ -1181,7 +1207,7 @@ bool corelib::deleteDesktopFile(const QString &prefix_name, const QString &dir_n
     QString fileName;
 
     //FIXME:
-    QString base_icon = QString("%1/.local/share/applications/").arg(QDir::homePath());
+    QString base_icon = QString("%1/applications/").arg(this->getGenericDataLocation());
 
     fileName = base_icon;
     fileName.append(APP_SHORT_NAME);
@@ -1520,7 +1546,7 @@ bool corelib::killWineServer(const QString &prefix_path, const QString &pid){
         if (info.isSymLink()) {
             QString fileName = info.symLinkTarget();
 #ifdef DEBUG
-            qDebug()<< "Traget for: " << info.filePath() << " is: " << fileName;
+            qDebug()<< "Target for: " << info.filePath() << " is: " << fileName;
 #endif
             if ((!fileName.contains("wine") && !fileName.contains(".exe")) || fileName.contains(APP_SHORT_NAME)){
                 message = "Not an wine process.";
@@ -1957,14 +1983,13 @@ bool corelib::exportPrefixesConfiguration(void){
     QStringList list = db_prefix.getPrefixList();
     QDir dir;
     QFile file;
-    QString home_path = dir.homePath();
     for (int i = 0; i < list.size(); ++i){
-        QString path = home_path;
+        QString path = this->getGenericDataLocation();
         QString prefix_name = list.at(i);
         QHash<QString,QString> result = db_prefix.getByName(prefix_name);
         QString prefix_path=result.value("path");
 
-        path.append("/.local/share/wineprefixes/");
+        path.append("/wineprefixes/");
 
         if (!dir.mkpath(path))
             return false;
@@ -1997,8 +2022,8 @@ QStringList corelib::importPrefixesConfiguration(void){
     QStringList list = db_prefix.getPrefixList();
     QDir dir;
     QFile file;
-    QString path = dir.homePath();
-    path.append("/.local/share/wineprefixes/");
+    QString path = this->getGenericDataLocation();
+    path.append("/wineprefixes/");
 
 
     dir.setFilter(QDir::Dirs | QDir::NoDotAndDotDot);
