@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2021 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -46,6 +46,7 @@
 #include <QDesktopServices>
 #include <QUrl>
 #include <QTranslator>
+#include <QStandardPaths>
 #include <locale.h>
 
 #include "process.h"
@@ -133,7 +134,7 @@ public:
      * \param  key         Settings key.
      * \param  defaultVal  Default returned value.
      * \param  checkExist  If true - then we need to check exists file or dir by value or not.
-     * \return Return an a key value.
+     * \return Return a key value.
      */
     QVariant getSetting(const QString &group,
                         const QString &key,
@@ -297,19 +298,19 @@ public:
     QString getStrictEscapeString(QString string);
 
 
-    /*! \brief Gets mount string based on QuikMount type profile
+    /*! \brief Gets mount string based on QuickMount type profile
      *
      * \param profile	Profile type ID
      */
     QString getMountString(const int profile);
 
-    /*! \brief Gets mount image string based on QuikMount type profile
+    /*! \brief Gets mount image string based on QuickMount type profile
      *
      * \param profile	Profile type ID
      */
     QString getMountImageString(const int profile);
 
-    /*! \brief Gets umount string based on QuikMount type profile
+    /*! \brief Gets umount string based on QuickMount type profile
      *
      * \param profile	Profile type ID
      */
@@ -345,6 +346,14 @@ public:
      */
     bool removeDirectory(const QString &dirPath);
 
+    static const QString formatLocation(const QStringList &path);
+    static const QString getAppConfigLocation(const QStringList &path = QStringList());
+    static const QString getGenericConfigLocation(const QStringList &path = QStringList());
+    static const QString getAppDataLocation(const QStringList &path = QStringList());
+    static const QString getGenericDataLocation(const QStringList &path = QStringList());
+    static const QString getAppCacheLocation(const QStringList &path = QStringList());
+    static const QString getGenericCacheLocation(const QStringList &path = QStringList());
+
 private:
     /*! Define is library operate in CLI or GUI mode.
      * \note This is typically need for error message display.
@@ -378,7 +387,7 @@ private:
  * \brief This function returns a class of corelib type.
  *
  * Here we create an instance of corelib class and returns its pointer.
- * \return Return an a pointer to core lib class instance.
+ * \return Return a pointer to core lib class instance.
  * \note This function is exported from shared library.
  */
 extern "C" corelib* createCoreLib(const bool GUI_MODE);
